==> haskell-io-streams-1.5.1.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams
version: 1.5.1.0
id: io-streams-1.5.1.0-Jr5Q18rgJkN1NXr3uJxXfl
key: io-streams-1.5.1.0-Jr5Q18rgJkN1NXr3uJxXfl
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: Simple, composable, and easy-to-use stream I/O
description:
    /Overview/
    .
    The io-streams library contains simple and easy-to-use primitives for I/O
    using streams. Most users will want to import the top-level convenience
    module "System.IO.Streams", which re-exports most of the library:
    .
    @
    import           System.IO.Streams (InputStream, OutputStream)
    import qualified System.IO.Streams as Streams
    @
    .
    For first-time users, @io-streams@ comes with an included tutorial, which can
    be found in the "System.IO.Streams.Tutorial" module.
    .
    /Features/
    .
    The @io-streams@ user API has two basic types: @InputStream a@ and
    @OutputStream a@, and three fundamental I/O primitives:
    .
    @
    \-\- read an item from an input stream
    Streams.read :: InputStream a -> IO (Maybe a)
    .
    \-\- push an item back to an input stream
    Streams.unRead :: a -> InputStream a -> IO ()
    .
    \-\- write to an output stream
    Streams.write :: Maybe a -> OutputStream a -> IO ()
    @
    .
    Streams can be transformed by composition and hooked together with provided combinators:
    .
    @
    ghci> Streams.fromList [1,2,3::Int] >>= Streams.map (*10) >>= Streams.toList
    [10,20,30]
    @
    .
    Stream composition leaves the original stream accessible:
    .
    @
    ghci> input \<- Streams.fromByteString \"long string\"
    ghci> wrapped \<- Streams.takeBytes 4 input
    ghci> Streams.read wrapped
    Just \"long\"
    ghci> Streams.read wrapped
    Nothing
    ghci> Streams.read input
    Just \" string\"
    @
    .
    Simple types and operations in the IO monad mean straightforward and simple
    exception handling and resource cleanup using Haskell standard library
    facilities like '\''Control.Exception.bracket'\''.
    .
    @io-streams@ comes with:
    .
    * functions to use files, handles, concurrent channels, sockets, lists,
    vectors, and more as streams.
    .
    * a variety of combinators for wrapping and transforming streams, including
    compression and decompression using zlib, controlling precisely how many
    bytes are read from or written to a stream, buffering output using
    bytestring builders, folds, maps, filters, zips, etc.
    .
    * support for parsing from streams using @attoparsec@.
    .
    * support for spawning processes and communicating with them using streams.
category: Data, Network, IO-Streams
abi: 66c9e6b6a605516059c3f36ab41ec93c
exposed: True
exposed-modules:
    System.IO.Streams System.IO.Streams.Attoparsec
    System.IO.Streams.Attoparsec.ByteString
    System.IO.Streams.Attoparsec.Text System.IO.Streams.Builder
    System.IO.Streams.ByteString System.IO.Streams.Combinators
    System.IO.Streams.Concurrent System.IO.Streams.Core
    System.IO.Streams.Debug System.IO.Streams.File
    System.IO.Streams.Handle System.IO.Streams.Internal
    System.IO.Streams.List System.IO.Streams.Network
    System.IO.Streams.Process System.IO.Streams.Text
    System.IO.Streams.Tutorial System.IO.Streams.Vector
    System.IO.Streams.Zlib
hidden-modules: System.IO.Streams.Internal.Attoparsec
                System.IO.Streams.Internal.Network
                System.IO.Streams.Internal.Search
import-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-1.5.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-1.5.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/io-streams-1.5.1.0
hs-libraries: HSio-streams-1.5.1.0-Jr5Q18rgJkN1NXr3uJxXfl
depends:
    attoparsec-0.13.2.2-WGDHRY8MTWGzoRjbN9EJO base-4.12.0.0
    bytestring-0.10.8.2 network-2.8.0.0-xbHtkcSHJTFxVBp7aTame
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    zlib-bindings-0.1.1.5-H4nqFf2lce1F7T9rYy0Nar
haddock-interfaces: /usr/share/doc/haskell-io-streams/html/io-streams.haddock
haddock-html: /usr/share/doc/haskell-io-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-1.5.1.0-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams
version: 1.5.1.0
id: io-streams-1.5.1.0-ARrp9xtkjAMDJvKX3hLohn
key: io-streams-1.5.1.0-ARrp9xtkjAMDJvKX3hLohn
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: Simple, composable, and easy-to-use stream I/O
description:
    /Overview/
    .
    The io-streams library contains simple and easy-to-use primitives for I/O
    using streams. Most users will want to import the top-level convenience
    module "System.IO.Streams", which re-exports most of the library:
    .
    @
    import           System.IO.Streams (InputStream, OutputStream)
    import qualified System.IO.Streams as Streams
    @
    .
    For first-time users, @io-streams@ comes with an included tutorial, which can
    be found in the "System.IO.Streams.Tutorial" module.
    .
    /Features/
    .
    The @io-streams@ user API has two basic types: @InputStream a@ and
    @OutputStream a@, and three fundamental I/O primitives:
    .
    @
    \-\- read an item from an input stream
    Streams.read :: InputStream a -> IO (Maybe a)
    .
    \-\- push an item back to an input stream
    Streams.unRead :: a -> InputStream a -> IO ()
    .
    \-\- write to an output stream
    Streams.write :: Maybe a -> OutputStream a -> IO ()
    @
    .
    Streams can be transformed by composition and hooked together with provided combinators:
    .
    @
    ghci> Streams.fromList [1,2,3::Int] >>= Streams.map (*10) >>= Streams.toList
    [10,20,30]
    @
    .
    Stream composition leaves the original stream accessible:
    .
    @
    ghci> input \<- Streams.fromByteString \"long string\"
    ghci> wrapped \<- Streams.takeBytes 4 input
    ghci> Streams.read wrapped
    Just \"long\"
    ghci> Streams.read wrapped
    Nothing
    ghci> Streams.read input
    Just \" string\"
    @
    .
    Simple types and operations in the IO monad mean straightforward and simple
    exception handling and resource cleanup using Haskell standard library
    facilities like '\''Control.Exception.bracket'\''.
    .
    @io-streams@ comes with:
    .
    * functions to use files, handles, concurrent channels, sockets, lists,
    vectors, and more as streams.
    .
    * a variety of combinators for wrapping and transforming streams, including
    compression and decompression using zlib, controlling precisely how many
    bytes are read from or written to a stream, buffering output using
    bytestring builders, folds, maps, filters, zips, etc.
    .
    * support for parsing from streams using @attoparsec@.
    .
    * support for spawning processes and communicating with them using streams.
category: Data, Network, IO-Streams
abi: 7e950ee77cb11dee8043c841224d2be7
exposed: True
exposed-modules:
    System.IO.Streams System.IO.Streams.Attoparsec
    System.IO.Streams.Attoparsec.ByteString
    System.IO.Streams.Attoparsec.Text System.IO.Streams.Builder
    System.IO.Streams.ByteString System.IO.Streams.Combinators
    System.IO.Streams.Concurrent System.IO.Streams.Core
    System.IO.Streams.Debug System.IO.Streams.File
    System.IO.Streams.Handle System.IO.Streams.Internal
    System.IO.Streams.List System.IO.Streams.Network
    System.IO.Streams.Process System.IO.Streams.Text
    System.IO.Streams.Tutorial System.IO.Streams.Vector
    System.IO.Streams.Zlib
hidden-modules: System.IO.Streams.Internal.Attoparsec
                System.IO.Streams.Internal.Network
                System.IO.Streams.Internal.Search
import-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-1.5.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-1.5.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/io-streams-1.5.1.0
hs-libraries: HSio-streams-1.5.1.0-ARrp9xtkjAMDJvKX3hLohn
depends:
    attoparsec-0.13.2.2-IYmscZi60PM1VHlw2sOR1C base-4.12.0.0
    bytestring-0.10.8.2 network-2.8.0.0-EWiez0ajBalJ2cORFP4yEt
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    zlib-bindings-0.1.1.5-H4nqFf2lce1F7T9rYy0Nar
haddock-interfaces: /usr/share/doc/haskell-io-streams/html/io-streams.haddock
haddock-html: /usr/share/doc/haskell-io-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
